pub enum CopyError {
OutOfMemory,
OffsetOutOfBounds,
InvalidLayout,
}Expand description
An error that may occur during a copy operation.
Variants
OutOfMemory
Copy would exceed the end of the allocation
OffsetOutOfBounds
Requested to copy to an offset outside the bounds of the allocation
InvalidLayout
Computed invalid layout for copy operation, probably caused by incredibly large size, offset, or min-alignment parameters