pub fn copy_from_slice_to_offset_with_align<T: Copy, S: Slab>(
src: &[T],
dst: &mut S,
start_offset: usize,
min_alignment: usize,
) -> Result<CopyRecord, CopyError>Expand description
Copies from slice into the memory represented by dst starting at a minimum location
of start_offset bytes past the start of dst.
start_offsetis the offset into the allocation represented bydst, in bytes, before which any copied data will certainly not be placed. However, the actual beginning of the copied data may not be exactly atstart_offsetif padding bytes are needed to satisfy alignment requirements. The actual beginning of the copied bytes is contained in the returnedCopyRecord.min_alignmentis the minimum alignment to which the copy will be aligned. The copy may not actually be aligned tomin_alignmentdepending on the alignment requirements ofTand the underlying allocation.- The whole data of the slice will be copied directly, so, alignment between elements
ignores
min_alignment.
- The whole data of the slice will be copied directly, so, alignment between elements
ignores
Safety
This function is safe on its own, however it is very possible to do unsafe things if you read the copied data in the wrong way. See the crate-level Safety documentation for more.