pub fn copy_into_maybe_uninit_slice<'a, T>(
src: &[T],
dst: &'a mut [MaybeUninit<T>],
) -> &'a mut [T]where
T: Copy,Expand description
Copies the elements from src to dst, returning a mutable reference to the now initialized contents of dst.
If T does not implement Copy, use clone_into_maybe_uninit_slice
This is similar to slice::copy_from_slice. This is identical to the implementation of the method
write_to_slice on MaybeUninit, but that API is as yet unstable.
Panics
This function will panic if the two slices have different lengths.