CopyRecord

Struct CopyRecord 

pub struct CopyRecord {
    pub copy_start_offset: usize,
    pub copy_end_offset: usize,
    pub copy_end_offset_padded: usize,
}
Record of the results of a copy operation

Fields

copy_start_offset: usize

The offset from the start of the allocation, in bytes, at which the copy operation began to write data.

Not necessarily equal to the start_offset, since this offset includes necessary padding to assure alignment.

copy_end_offset: usize

The offset from the start of the allocation, in bytes, at which the copy operation no longer wrote data.

This does not include any padding at the end necessary to maintain alignment requirements.

copy_end_offset_padded: usize

The offset from the start of the allocation, in bytes, at which the copy operation no longer wrote data, plus any padding necessary to maintain derived alignment requirements.