pub(crate) fn align_offset_up_to(
ptr: usize,
offset: usize,
align: usize,
) -> Option<usize>Expand description
Given pointer and offset, returns a new offset aligned to align.
align must be a power of two and >= 1 or else the result is meaningless.